package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwBdAccassitem;
import com.dhcc.finance.main.model.CwBdAccassitemLike;
import com.github.pagehelper.PageInfo;

public interface AssistedAccountingService {

	/**
	 * 功能描述:新增辅助核算项接口
	 * @param cwBdAccassitem
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月3日 下午3:37:52
	 *@修改日志:
	 */
	RestfulResponse<Object, CurrencyMeta> addAssistedAccounting(CwBdAccassitem cwBdAccassitem);
	/**
	 * 功能描述:查询辅助核算项接口
	 * @param cwBdAccassitemLike
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwBdAccassitem>,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月3日 下午3:38:35
	 *@修改日志:
	 */
	RestfulResponse<PageInfo<CwBdAccassitem>, CurrencyMeta> searchAssistedAccountingInfo(
			CwBdAccassitemLike cwBdAccassitemLike, int pageNum, int pageSize, int navigatePages);
	/**
	 * 功能描述:修改辅助核算项接口
	 * @param cwBdAccassitem
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月4日 上午9:42:18
	 *@修改日志:
	 */
	RestfulResponse<Object, CurrencyMeta> updateCwBdAccassitemByPk(CwBdAccassitem cwBdAccassitem);

	/**
	 * 功能描述:删除辅助核算项接口
	 * @param pkAccassitem
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月4日 上午9:42:49
	 *@修改日志:
	 */
	RestfulResponse<Object, CurrencyMeta> deleteCwBdAccassByPk(String pkAccassitem);
	/**
	 * 功能描述:更新状态码
	 * @param cwBdAccassitem
	 * @return RestfulResponse<Integer,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月4日 下午5:09:40
	 *@修改日志:
	 */
	RestfulResponse<Integer, CurrencyMeta> updateEnablestate(CwBdAccassitem cwBdAccassitem);
	/**
	 * 功能描述:查询辅助核算项所有数据
	 * @return RestfulResponse<List<CwBdAccassitem>,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月11日 下午7:40:47
	 *@修改日志:
	 */
	RestfulResponse<List<CwBdAccassitem>, CurrencyMeta> searchCwBdAccassitem();




}
